@@ -3,6 +3,7 @@ import select
 import struct
 import socket
 import Queue
+import copy
 import os
 import io
 
@@ -124,6 +125,7 @@ class netlink_io(threading.Thread):
         self.socket.bind(groups)
         self.marshal = marshal(self.socket)
         self.listeners = {}
+        self.mirror = False
         self.poll = select.poll()
         (self.ctlr, self.control) = os.pipe()
         self.register(self.ctlr)
@@ -161,6 +163,8 @@ class netlink_io(threading.Thread):
                         key = msg['header']['sequence_number']
                         if key not in self.listeners:
                             key = 0
+                        if self.mirror and key != 0:
+                            self.listeners[0].put(copy.deepcopy(msg))
                         if key in self.listeners:
                             self.listeners[key].put(msg)
 
@@ -189,6 +193,9 @@ class netlink(object):
             self.__nonce += 1
         return self.__nonce
 
+    def mirror(self, operate=True):
+        self.io_thread.mirror = operate
+
     def monitor(self, operate=True):
         if operate:
             self.listeners[0] = Queue.Queue()
@@ -205,11 +212,11 @@ class netlink(object):
         '''
         Get a message from a queue
         '''
-        assert key in self.listeners
+        queue = self.listeners[key]
 
         result = []
         while True:
-            msg = self.listeners[key].get()
+            msg = queue.get()
             if msg['header']['error'] is not None:
                 raise msg['header']['error']
             if msg['header']['type'] != NLMSG_DONE:
@@ -217,6 +224,16 @@ class netlink(object):
             if (msg['header']['type'] == NLMSG_DONE) or \
                (not msg['header']['flags'] & NLM_F_MULTI):
                 break
+        # not default queue
+        if key != 0:
+            # delete the queue
+            del self.listeners[key]
+            # get remaining messages from the queue and
+            # re-route them to queue 0 or drop
+            while not queue.empty():
+                msg = queue.get()
+                if 0 in self.listeners:
+                    self.listeners[0].put(msg)
         return result
 
     def nlm_request(self, msg, msg_type,
